package ch.zhaw.gartenverwaltung.io;

import ch.zhaw.gartenverwaltung.types.HardinessZone;
import ch.zhaw.gartenverwaltung.types.Plant;
import com.fasterxml.jackson.databind.ObjectMapper;
import com.fasterxml.jackson.datatype.jsr310.JavaTimeModule;
import com.fasterxml.jackson.datatype.jsr310.deser.MonthDayDeserializer;

import java.io.IOException;
import java.net.URL;
import java.time.MonthDay;
import java.time.format.DateTimeFormatter;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

public class JsonPlantDatabase implements PlantDatabase {
    private final URL dataSource = getClass().getResource("plantdb.json");

    private final static JavaTimeModule timeModule = new JavaTimeModule();
    static {
        DateTimeFormatter dateFormat = DateTimeFormatter.ofPattern("MM-dd");
        MonthDayDeserializer dateDeserializer = new MonthDayDeserializer(dateFormat);
        timeModule.addDeserializer(MonthDay.class, dateDeserializer);
    }

    @Override
    public List<Plant> getPlantList(HardinessZone zone) throws IOException {
        List<Plant> result = Collections.emptyList();

        if (dataSource != null) {
            ObjectMapper mapper = new ObjectMapper();
            mapper.registerModule(timeModule);

            result = mapper.readerForListOf(Plant.class).readValue(dataSource);
        }

        return result;
    }

    @Override
    public Optional<Plant> getPlantById(long id) {
        return Optional.empty();
    }
}
